%% EDA Analysis - Trial configuration file
% This is an example trial definition file for the exported vp001_acq.mat file containing EDA data.
% The EDA data were recorded with a BIOPAC MP150 system using the GSR100C module.
%
% You can find more information about the experiment itself and the possibilities for evaluation in
% the detailed documentation.

% Tobias Otto
% 1.0
% 24.11.2021

%% Please never rename variables !!!
%% Really... never!!!

%% Version of trialDefinition file
% This variable is used by the EDA-Analysis app and describes how the data is stored in the
% TrialDefinition file.
% Please do not change this value if you do not know exactly what you are doing.
% This variable is used from version 5.14 (10.10.2023) of the EDA-Analysis app.
trialDefVersion = 2.0;

%% Enter the number of trials
numTrials = 20;

%% Trial separation
% Enter the start time of the first, second, third, ..., last trial AND
% the time when the last trial ends.
% The EDAAnalysis App uses these values to 'cut' the recorded EDA data
% into trial pieces.
%
% If your recording started with the first trial of the presentation
% program the first entry should be 0.
%
% PLEASE don't forget the last entry: the time when the last trial ends
%
% All time entries are entered in seconds
trialSep = [10 30 50 70 90 110 130 150 170 191 211 231 251 271 291 311 331 351 371 391 411];

% ====>>> OR <<<====
% Use the variables trialStart and trialStop to 'cut' a long recording into
% trials or subtrials. Sometimes only special parts of a recording are
% needed for analysis. Use this two variables otherwise leave them empty.
%
% If these variables are used the variable trialSep needs to be empty !!!
% triaSep = [] !!! Otherwise an error occurs.
trialStart  = [];
trialStop   = [];


%% Stimulus onset
% Enter the time of the stimulus when it first appeared on the screen.
% The EDAAnalysis app takes into account the data used to calculate the
% EDA from the stimulus onset to the end of the trial.
% If the complete trial from trial start to trial end is to be evaluated,
% stimOnset and trialStart must contain the same times.
%
% All time entries are entered in seconds
stimOnset = [10 30 50 70 90 110 130 150 170 191 211 231 251 271 291 311 331 351 371 391];

%% Marking positions in trials
% If you want to mark special positions in time when plotting the EDA you
% can define the time, the color of the marker and the name here.
% These entries have no influence of the EDA analysis, BUT each entry here
% will result in an extra Excel file when using exportEDA.
%
% Each marker needs three entries for each trial that what defined above:
%   * Positions in time (all entries in seconds). If a marker doesn't exist
%     in a trial it has to be marked as -1 for that trial.
%   * A name of the marker
%   * Color of the marker
%               'y' --> [1 1 0] --> yellow
%               'm' --> [1 0 1] --> magenta
%               'c' --> [0 1 1] --> cyan
%               'g' --> [0 1 0] --> green
%               'b' --> [0 0 1] --> blue
%               'w' --> [1 1 1] --> white
%               'k' --> [0 0 0] --> black

% Leave variable empty in case there are no optional markers !!!
% This variable must not be omitted, otherwise an error occurs!
% sPos = [];

% Extra marker: CS+
sPos{1}.time        = [33 73 93 153 194 234 254 294 334 374];
sPos{1}.color       = 'm';
sPos{1}.name        = 'CS+';
sPos{1}.duration    = 2;
sPos{1}.description = 'CS+ Stimulus';

% Extra marker: CS-
sPos{2}.time        = [13 53 113 133 174 214 274 314 354 394];
sPos{2}.color       = 'c';
sPos{2}.name        = 'CS-';
sPos{2}.duration    = 2;
sPos{2}.description = 'CS- Stimulus';

% Extra marker: CS+S
sPos{3}.time        = [93 153 234 294 374];
sPos{3}.color       = 'g';
sPos{3}.name        = 'CS+S';
sPos{3}.duration    = 2;
sPos{3}.description = 'CS+ Stimulus (variant 1)';

% Extra marker: CS+W
sPos{4}.time        = [33 73 194 254 334];
sPos{4}.color       = 'b';
sPos{4}.name        = 'CS+W';
sPos{4}.duration    = 2;
sPos{4}.description = 'CS+ Stimulus (variant 2)';

% Extra marker: UCS
sPos{5}.time        = [99 159 240 300 380];
sPos{5}.color       = 'k';
sPos{5}.name        = 'UCS';
sPos{5}.duration    = 2;
sPos{5}.description = 'UCS Stimulus';

% Extra marker: noUCS_CS+
sPos{6}.time        = [39 79 200 260 340];
sPos{6}.color       = 'g';
sPos{6}.name        = 'noUCS_CS+';
sPos{6}.duration    = 2;
sPos{6}.description = 'No UCS available, but a CS+';

% Extra marker: noUCS_CS-
sPos{7}.time        = [19 59 119 139 180 220 280 320 360 400];
sPos{7}.color       = 'g';
sPos{7}.name        = 'noUCS_CS-';
sPos{7}.duration    = 2;
sPos{7}.description = 'No UCS available, but a CS-';

%% Sampling rate of your setup
% Enter sampling rate for the EDA recording in HZ
samplRate = 1000;

%% Define recording system
% This defines handling and computation of the raw data that are loaded
% into the plotEDATrial program.
%
% Use only the following entries:
% For a Biopac recording system (GSR100C)   --> 'GSR100C'
% For a BrainVision Recorder system      	--> 'VisionRecorder'
recordingSystem = 'GSR100C';

%% BIDS information (optional and for BIDS export only)
% If you plan to export your data in BIDS format, the following data is mandatory and cannot be
% omitted.

% Presentation time of the stimulus in s whose onset time was specified above under stimOnset.
bids.stimDuration = 2;

% Subject name
bids.subjectName = '0815';

% Number of the recorded session. If you only recorded one data set enter 1 here
bids.session        = 1;

% If you have more than one recording in one session enter the number here. In case you have only
% one data set enter 1 here.
bids.run            = 1;

% Enter a short (!) task name here. E.g.: exp, acq, reinst, etc.
bids.task           = 'acq';

% A brief description of the task in a few sentences, containing all the essential information
% about the task in the experiment and the procedure.
bids.taskDescription = 'Use this file as an example for your trialDefinition files.';

% Enter institute information.
bids.info           = 'Ruhr University Bochum, Faculty of Psychology, Cognitive Psychology, Bochum, Germany';

% Enter contact information.
bids.contact        = 'tobias.otto@ruhr-uni-bochum.de';

